nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

AplllockCnfg

Struct AplllockCnfg 

#[repr(transparent)]
pub struct AplllockCnfg(pub u32);
APLL LOCK Configuration Register

Tuple Fields

0: u32

Implementations

Source

impl AplllockCnfg

pub const fn lock_time(&self) -> u32

Configures the number of reference clocks to count before APLL is considered locked.

pub const fn set_lock_time(&mut self, val: u32)

Configures the number of reference clocks to count before APLL is considered locked.