nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

SplllockCnfg

Struct SplllockCnfg 

#[repr(transparent)]
pub struct SplllockCnfg(pub u32);
SPLL LOCK Configuration Register

Tuple Fields

0: u32

Implementations

Source

impl SplllockCnfg

pub const fn lock_time(&self) -> u32

Configures the number of reference clocks to count before SPLL is considered locked.

pub const fn set_lock_time(&mut self, val: u32)

Configures the number of reference clocks to count before SPLL is considered locked.